@@ -496,8 +496,13 @@ amdgpu_present_has_async_flip(ScreenPtr screen)
 Bool
 amdgpu_present_screen_init(ScreenPtr screen)
 {
-	if (amdgpu_present_has_async_flip(screen))
+	ScrnInfoPtr scrn = xf86ScreenToScrn(screen);
+	AMDGPUInfoPtr info = AMDGPUPTR(scrn);
+
+	if (amdgpu_present_has_async_flip(screen)) {
 		amdgpu_present_screen_info.capabilities |= PresentCapabilityAsync;
+		info->can_async_flip = TRUE;
+	}
 
 	if (!present_screen_init(screen, &amdgpu_present_screen_info)) {
 		xf86DrvMsg(xf86ScreenToScrn(screen)->scrnIndex, X_WARNING,
